pub struct ConnectionHandle { /* private fields */ }Expand description
A handle given to a task that needs to ban, disconnect, check if the peer should be banned or check the peer is still connected.
Implementations
Sourceimpl ConnectionHandle
impl ConnectionHandle
pub fn closed(&self) -> WaitForCancellationFutureOwned ⓘ
Sourcepub fn check_should_ban(&mut self) -> Option<BanPeer>
pub fn check_should_ban(&mut self) -> Option<BanPeer>
Returns if this peer has been banned and the Duration of that ban.
Sourcepub fn send_close_signal(&self)
pub fn send_close_signal(&self)
Sends the signal to the connection task to disconnect.