pub struct HandleBuilder { /* private fields */ }Expand description
A ConnectionHandle builder.
Implementations
Sourceimpl HandleBuilder
impl HandleBuilder
Sourcepub fn with_permit(self, permit: Option<OwnedSemaphorePermit>) -> Self
pub fn with_permit(self, permit: Option<OwnedSemaphorePermit>) -> Self
Sets the permit for this connection.
Sourcepub fn build(self) -> (ConnectionGuard, ConnectionHandle)
pub fn build(self) -> (ConnectionGuard, ConnectionHandle)
Builds the ConnectionGuard which should be handed to the connection task and the ConnectionHandle.
This will panic if a permit was not set HandleBuilder::with_permit